@@ -18,8 +18,9 @@ import requests
 import json
 
 # Code zappette
-code_Fb= "35782633"
-log.msg("*****************************")
+#code_Fb= "35782633"
+#log.msg("*****************************")
+
 class Freebox(IPlugin):
 	def __init__(self):
 		super(Freebox, self).__init__()
